import { Directive, ElementRef, Renderer, Input, Output, HostListener, EventEmitter, NgZone } from '@angular/core';
var AngularEchartsDirective = (function () {
    function AngularEchartsDirective(el, renderer, _ngZone) {
        this.el = el;
        this.renderer = renderer;
        this._ngZone = _ngZone;
        this.theme = '';
        this.chartInit = new EventEmitter();
        this.chartClick = new EventEmitter();
        this.chartDblClick = new EventEmitter();
        this.chartMouseDown = new EventEmitter();
        this.chartMouseUp = new EventEmitter();
        this.chartMouseOver = new EventEmitter();
        this.chartMouseOut = new EventEmitter();
        this.chartGlobalOut = new EventEmitter();
        this.chartContextMenu = new EventEmitter();
        this.chartDataZoom = new EventEmitter();
        this.myChart = null;
        this.currentWindowWidth = null;
    }
    AngularEchartsDirective.prototype.createChart = function () {
        var _this = this;
        this.theme = this.theme || '';
        this.currentWindowWidth = window.innerWidth;
        if (this.theme) {
            return this._ngZone.runOutsideAngular(function () { return echarts.init(_this.el.nativeElement, _this.theme); });
        }
        else {
            return this._ngZone.runOutsideAngular(function () { return echarts.init(_this.el.nativeElement); });
        }
    };
    AngularEchartsDirective.prototype.updateChart = function () {
        this.myChart.setOption(this.options);
        this.myChart.resize();
    };
    AngularEchartsDirective.prototype.onWindowResize = function (event) {
        if (event.target.innerWidth !== this.currentWindowWidth) {
            this.currentWindowWidth = event.target.innerWidth;
            if (this.myChart) {
                this.myChart.resize();
            }
        }
    };
    AngularEchartsDirective.prototype.ngOnChanges = function (changes) {
        if (changes['dataset']) {
            this.onDatasetChange(this.dataset);
        }
        if (changes['options']) {
            this.onOptionsChange(this.options);
        }
        if (changes['loading']) {
            this.onLoadingChange(this.loading);
        }
    };
    AngularEchartsDirective.prototype.ngOnDestroy = function () {
        if (this.myChart) {
            this.myChart.dispose();
            this.myChart = null;
        }
    };
    AngularEchartsDirective.prototype.onOptionsChange = function (opt) {
        if (opt) {
            if (!this.myChart) {
                this.myChart = this.createChart();
                this.chartInit.emit(this.myChart);
                this.registerEvents(this.myChart);
            }
            if (this.hasData()) {
                this.updateChart();
            }
            else if (this.dataset && this.dataset.length) {
                this.mergeDataset(this.dataset);
                this.updateChart();
            }
        }
    };
    AngularEchartsDirective.prototype.onDatasetChange = function (dataset) {
        if (this.myChart && this.options) {
            if (!this.options.series) {
                this.options.series = [];
            }
            this.mergeDataset(dataset);
            this.updateChart();
        }
    };
    AngularEchartsDirective.prototype.onLoadingChange = function (loading) {
        if (this.myChart) {
            if (loading) {
                this.myChart.showLoading();
            }
            else {
                this.myChart.hideLoading();
            }
        }
    };
    AngularEchartsDirective.prototype.mergeDataset = function (dataset) {
        for (var i = 0, len = dataset.length; i < len; i++) {
            if (!this.options.series[i]) {
                this.options.series[i] = { data: dataset[i] };
            }
            else {
                this.options.series[i].data = dataset[i];
            }
        }
    };
    AngularEchartsDirective.prototype.hasData = function () {
        if (!this.options.series || !this.options.series.length) {
            return false;
        }
        for (var _i = 0, _a = this.options.series; _i < _a.length; _i++) {
            var serie = _a[_i];
            if (serie.data && serie.data.length > 0) {
                return true;
            }
        }
        return false;
    };
    AngularEchartsDirective.prototype.registerEvents = function (myChart) {
        var _this = this;
        if (myChart) {
            myChart.on('click', function (e) { _this.chartClick.emit(e); });
            myChart.on('dblClick', function (e) { _this.chartDblClick.emit(e); });
            myChart.on('mousedown', function (e) { _this.chartMouseDown.emit(e); });
            myChart.on('mouseup', function (e) { _this.chartMouseUp.emit(e); });
            myChart.on('mouseover', function (e) { _this.chartMouseOver.emit(e); });
            myChart.on('mouseout', function (e) { _this.chartMouseOut.emit(e); });
            myChart.on('globalout', function (e) { _this.chartGlobalOut.emit(e); });
            myChart.on('contextmenu', function (e) { _this.chartContextMenu.emit(e); });
            myChart.on('dataZoom', function (e) { _this.chartDataZoom.emit(e); });
        }
    };
    return AngularEchartsDirective;
}());
export { AngularEchartsDirective };
AngularEchartsDirective.decorators = [
    { type: Directive, args: [{
                selector: '[echarts]'
            },] },
];
AngularEchartsDirective.ctorParameters = function () { return [
    { type: ElementRef, },
    { type: Renderer, },
    { type: NgZone, },
]; };
AngularEchartsDirective.propDecorators = {
    'options': [{ type: Input },],
    'dataset': [{ type: Input },],
    'theme': [{ type: Input },],
    'loading': [{ type: Input },],
    'chartInit': [{ type: Output },],
    'chartClick': [{ type: Output },],
    'chartDblClick': [{ type: Output },],
    'chartMouseDown': [{ type: Output },],
    'chartMouseUp': [{ type: Output },],
    'chartMouseOver': [{ type: Output },],
    'chartMouseOut': [{ type: Output },],
    'chartGlobalOut': [{ type: Output },],
    'chartContextMenu': [{ type: Output },],
    'chartDataZoom': [{ type: Output },],
    'onWindowResize': [{ type: HostListener, args: ['window:resize', ['$event'],] },],
};
//# sourceMappingURL=angular-echarts.directive.js.map